/// <reference types="node" />
import * as net from "net";
/**
 * Class for handling client connections to our persistent service (e.g. daemon mode)
 * @export
 * @class DaemonClient
 */
export declare class DaemonClient {
    private mClient;
    private mServer;
    /**
     * Undocumented paramter to cause daemon to shutdown
     * @private
     * @static
     * @memberof DaemonClient
     */
    private static readonly STOP_KEY;
    private static readonly ZOWE_DEAMON_ID;
    /**
     * Creates an instance of DaemonClient.
     * @param {net.Socket} mClient
     * @param {net.Server} mServer
     * @memberof DaemonClient
     */
    constructor(mClient: net.Socket, mServer: net.Server);
    /**
     * Run an instance of this client and wait for proper events
     * @memberof DaemonClient
     */
    run(): void;
    /**
     * End event handler triggered when client disconnects
     * @private
     * @memberof DaemonClient
     */
    private end;
    /**
     * Close event handler triggered when client closes connection
     * @private
     * @memberof DaemonClient
     */
    private close;
    /**
     * Data event handler triggered for whenever data comes in on a connection
     * @private
     * @param {Buffer} data
     * @memberof DaemonClient
     */
    private data;
}
